@@ -22,6 +22,7 @@ import struct
 import os
 import ctypes
 import sys
+import json
 
 if os.name == 'nt':
     DLL_NAME = 'cfscc.dll'
@@ -51,8 +52,6 @@ FSCC_TIMEOUT, FSCC_INCORRECT_MODE, \
     FSCC_INVALID_ACCESS, \
     FSCC_INVALID_PARAMETER = 16000, 16001, 16002, 16003, 16004, 16005
 
-NOT_SUPPORTED_TEXT = 'This feature isn\'t supported on this port.'
-
 
 class PortNotFoundError(OSError):
     def __init__(self, port_num=None):
@@ -189,40 +188,6 @@ class Port(object):
                 if i == index:
                     setattr(self, '_%s' % r, value)
 
-        # Note: clears registers
-        def import_from_file(self, import_file):
-            """Reads and stores the register values from a file."""
-            import_file.seek(0, os.SEEK_SET)
-
-            for line in import_file:
-                try:
-                    line = str(line, encoding='utf8')
-                except:
-                    pass
-
-                if line[0] != '#':
-                    d = line.split('=')
-                    reg_name, reg_val = d[0].strip().upper(), d[1].strip()
-
-                    if reg_name in self.editable_register_names:
-                        if reg_val[0] == '0' and reg_val[1] in ['x', 'X']:
-                            reg_val = int(reg_val, 16)
-                        else:
-                            reg_val = int(reg_val)
-
-                        setattr(self, reg_name, reg_val)
-
-        def export_to_file(self, export_file):
-            """Writes the current register values to a file."""
-            for reg_name in self.editable_register_names:
-                if reg_name in self.writeonly_register_names:
-                    continue
-
-                value = getattr(self, reg_name)
-
-                if value >= 0:
-                    export_file.write('%s = 0x%08x\n' % (reg_name, value))
-
         def __len__(self):
             return len(self.register_names)
 
@@ -248,6 +213,25 @@ class Port(object):
                     reg_values.append((reg_name, None))
             return str(reg_values)
 
+        def _to_json(self):
+            ol = {}
+
+            for reg_name, reg_value in self:
+                if reg_value is not None:
+                    ol[reg_name] = hex(reg_value)
+
+            return ol
+
+        def to_json(self, *args, **kwargs):
+            return json.dumps(self._to_json(), *args, **kwargs)
+
+        def from_json(self, json):
+            for name, value in json.items():
+                try:
+                    setattr(self, name, int(value, 0))
+                except AttributeError:
+                    pass
+
     class MemoryCap(object):
 
         def __init__(self, port=None):
@@ -284,6 +268,19 @@ class Port(object):
 
         output = property(fset=_set_omemcap, fget=_get_omemcap)
 
+        def _to_json(self):
+            return {
+                'input': self.input,
+                'output': self.output,
+            }
+
+        def to_json(self, *args, **kwargs):
+            return json.dumps(self._to_json(), *args, **kwargs)
+
+        def from_json(self, json):
+            self.input = json['input']
+            self.output = json['output']
+
     def __init__(self, port_num, append_status=True, append_timestamp=True):
         self._handle = ctypes.c_void_p()
 
@@ -421,11 +418,11 @@ class Port(object):
         matches = ctypes.c_uint()
 
         if timeout:
-            e = lib.fscc_track_interrupts_with_timeout(self._handle, interrupts,
-                                           ctypes.byref(matches), int(timeout))
+            e = lib.fscc_track_interrupts_with_timeout(
+                self._handle, interrupts, ctypes.byref(matches), int(timeout))
         else:
-            e = lib.fscc_track_interrupts_with_blocking(self._handle, interrupts,
-                                            ctypes.byref(matches))
+            e = lib.fscc_track_interrupts_with_blocking(
+                self._handle, interrupts, ctypes.byref(matches))
 
         Port._check_error(e)
 
@@ -512,7 +509,8 @@ class Port(object):
 
         if timeout:
             e = lib.fscc_read_with_timeout(self._handle, data, int(size),
-                                           ctypes.byref(bytes_read), int(timeout))
+                                           ctypes.byref(bytes_read),
+                                           int(timeout))
         else:
             e = lib.fscc_read_with_blocking(self._handle, data, int(size),
                                             ctypes.byref(bytes_read))
@@ -533,6 +531,29 @@ class Port(object):
     def close(self):
         lib.fscc_disconnect(self._handle)
 
+    def _to_json(self):
+        return {
+            'append_status': self.append_status,
+            'append_timestamp': self.append_timestamp,
+            'ignore_timeout': self.ignore_timeout,
+            'tx_modifiers': self.tx_modifiers,
+            'rx_multiple': self.rx_multiple,
+            'registers': self.registers._to_json(),
+            'memory_cap': self.memory_cap._to_json(),
+        }
+
+    def to_json(self, *args, **kwargs):
+        return json.dumps(self._to_json(), *args, **kwargs)
+
+    def from_json(self, json):
+        self.append_status = json['append_status']
+        self.append_timestamp = json['append_timestamp']
+        self.ignore_timeout = json['ignore_timeout']
+        self.tx_modifiers = json['tx_modifiers']
+        self.rx_multiple = json['rx_multiple']
+        self.registers.from_json(json['registers'])
+        self.memory_cap.from_json(json['memory_cap'])
+
     def __str__(self):
         if os.name == 'nt':
             return 'FSCC{}'.format(self._port_num)
